<?php

namespace Drupal\content_readability\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactory;

/**
 * Displays the extlink settings form.
 */
class ContentReadabilityAdminSettingsForm extends ConfigFormBase {

  /**
   * Configuration Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * Constructor.
   */
  public function __construct(ConfigFactory $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_readability.admin.config';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('content_readability.settings');

    $form['content_readability_threshold'] = [
      '#type' => 'select',
      '#title' => $this->t('Content Readability Threshold'),
      '#default_value' => $config->get('content_readability_threshold'),
      '#options' => [
        '1' => $this->t('First Grade'),
        '2' => $this->t('Second Grade'),
        '3' => $this->t('Third Grade'),
        '4' => $this->t('Fourth Grade'),
        '5' => $this->t('Fifth Grade'),
        '6' => $this->t('Sixth Grade'),
        '7' => $this->t('Seventh Grade'),
        '8' => $this->t('Eighth Grade'),
        '9' => $this->t('Ninth Grade'),
        '10' => $this->t('Tenth Grade'),
        '11' => $this->t('Eleventh Grade'),
        '12' => $this->t('Twelfth Grade'),
      ],
      '#description' => $this->t('Select the threshold.  The number corresponds
      to the education grade level a person needs to understand the content.  Scores will
      be graded on the deviation from the target grade level.'),
    ];

    $form['content_readability_help'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Content Readability Help'),
      '#default_value' => $config->get('content_readability_help'),
      '#maxlength' => NULL,
      '#description' => $this->t('Link to generic help about content readability
      Open to be customized for those with internal rules or an example page.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $this->configFactory->getEditable('content_readability.settings')
      ->set('content_readability_threshold', $values['content_readability_threshold'])
      ->set('content_readability_help', $values['content_readability_help'])
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['content_readability.settings'];
  }

}
